import Control from 'ol/control/Control';

class Bar extends Control {
    /**
  * @param {Options} [options] Options.
  */
    constructor (options) {
        options = options ? options : {};
        var element = options.element || document.createElement("div");
        element.classList.add('ol-unselectable', 'ol-control', 'ol-bar');
        element.style.pointerEvents = 'none';
        if (options.className) {
            var classes = options.className.split(' ').filter(function (className) {
                return className.length > 0;
            });
            element.classList.add.apply(element.classList, classes)
        }
        if (options.group) element.classList.add('ol-group');

        super({
            element: element,
            render: options.render,
            target: options.target,
        });
        this.set('toggleOne', options.toggleOne);
        this.set('autoDeactivate', options.autoDeactivate);

        this.controls_ = [];
        if (options.controls instanceof Array) {
            for (var i = 0; i < options.controls.length; i++) {
                this.addControl(options.controls[i]);
            }
        }
    }

    setVisible (val) {
        if (val) this.element.style.display = '';
        else this.element.style.display = 'none';
    }
    onActivateControl (e, ctrl) {
        if (this.get('toggleOne')) {
            if (e.active) {
                var n;
                //var ctrl = e.target;
                for (n = 0; n < this.controls_.length; n++) {
                    if (this.controls_[n] === ctrl) break;
                }
                // Not here!
                if (n == this.controls_.length) return;
                this.deactivateControls(this.controls_[n]);
            } else {
                // No one active > test auto activate
                if (!this.getActiveControls().length) {
                    for (var i = 0, c; c = this.controls_[i]; i++) {
                        if (c.get("autoActivate")) {
                            c.setActive(true);
                            break;
                        }
                    }
                }
            }
        }
    };
    getControlsByName (name) {
        var controls = this.getControls();
        return controls.filter(
            function (control) {
                return (control.get('name') === name);
            }
        );
    };
}

export default Bar;