/*
 * @Description: 
 * @Author: 王强
 * @Date: 2022-09-08 20:19:46
 * @LastEditTime: 2022-09-17 16:06:11
 * @LastEditors: 王强
 */
import { validateParams } from "../../lib/core"
import {
  Image as ImageLayer
} from 'ol/layer'
import { ImageStatic } from 'ol/source'
/**
 * @description:  根据自定义参数获取图层
 * @return {*}
 * @Author: 王强
 * @Date: 2022-09-08 20:41:26
 * @LastEditTime: Do not edit
 * @LastEditors: 王强
 * @param {*} params map value codekey
 */
export function getLayers (params) {
  validateParams(['map'], params)
  const { map, codeValue, codeKey } = params
  const layers = map.getLayers().getArray()
  if (!codeValue && !codeKey) {
    return layers
  }
  return layers.filter(layer => layer.get(codeKey) === codeValue)
}

/**
 * @description: 根据自定义参数移除
 * @return {*}
 * @Author: 王强
 * @Date: 2022-09-08 20:41:51
 * @LastEditTime: Do not edit
 * @LastEditors: 王强
 * @param {*} params
 */
export function removeLayers (params) {
  validateParams(['map', 'codeValue', 'codeKey'], params)
  const { map, codeValue, codeKey } = params
  const layers = map.getLayers().getArray()
  for (let i = 0; i < layers.length; i++) {
    const layer = layers[i]
    if (layer.get(codeKey) === codeValue) {
      map.removeLayer(layer)
      i--
    }
  }
}


/**
 * @description: 根据自定义参数显示或隐藏
 * @return {*}
 * @Author: 王强
 * @Date: 2022-09-08 20:41:51
 * @LastEditTime: Do not edit
 * @LastEditors: 王强
 * @param {*} params
 */
export function setLayersVisible (params) {
  validateParams(['map', 'codeValue', 'codeKey'], params)
  const layers = getLayers(params)
  layers.forEach(layer => layer.setVisible(params.visible))
}

/**
 * @Description: 添加图片图层
 * @params map 地图对象
 *         imageStaticOptions 图片数据源参数图层参数
 *         imageLayerOptions 图片图层参数
 *         codeKey  图层codeKey
 *         codeValue 图层codeValue
 * @author qiang wang
 * @date 2022/1/7
 */
export function addImageLayer (params) {
  validateParams(['map', 'codeValue', 'codeKey'], params)
  let { map, imageStaticOptions, imageLayerOptions, data } = params;
  imageStaticOptions = Object.assign({
    projection: 'EPSG:4326'
  }, imageStaticOptions)
  const imageSource = new ImageStatic(imageStaticOptions)
  imageLayerOptions = Object.assign({
    source: imageSource,
  }, imageLayerOptions)
  let imageLayer = new ImageLayer(imageLayerOptions)
  imageLayer.set('data', data)
  imageLayer.set(params.codeKey, params.codeValue)
  map.addLayer(imageLayer)
  return imageLayer
}

export default {
  getLayers,
  removeLayers,
  setLayersVisible,
  addImageLayer
}