import { validateParams } from "../../lib/core"
import { circular } from 'ol/geom/Polygon'
import Feature from "ol/Feature";
import Point from "ol/geom/Point";
import { Vector as VectorSource } from "ol/source";
import { Vector as VectorLayer } from "ol/layer";
import { Style, Stroke, Text, Fill, Circle } from "ol/style";
import { fromLonLat } from 'ol/proj'

function createRadarAreaFuture (params) {
    validateParams(['center', 'distance'], params)
    let polygon = circular(params.center, params.distance * 1000, 100)
    polygon = polygon.clone().transform('EPSG:4326', 'EPSG:3857')
    const circleFeature = new Feature({
        geometry: polygon,
        name: 'RADAR_ARAR'
    })
    return circleFeature
}

/**
 * @description:  创建雷达图标Feature
 * @return {*}
 * @Author: 王强
 * @Date: 2022-09-17 16:29:29
 * @LastEditTime: Do not edit
 * @LastEditors: 王强
 */

function createRadarFeature (location) {
    const feature = new Feature({
        type: 'icon',
        geometry: new Point(fromLonLat(location)),
        name: 'RADAR_ICON'
    })
    return feature
}

function radarStyle (feature) {
    const name = feature.get("name")
    switch (name) {
        case 'RADAR_ICON':
            return new Style({
                image: new Circle({
                    radius: 5,
                    fill: new Fill({
                        color: "red",
                    }),
                }),
                text: new Text({
                    text: "",
                }),
            });
        case 'RADAR_ARAR':
            return new Style({
                stroke: new Stroke({
                    color: '#627386',
                    width: 2
                })
            })
        default:
            break;
    }
}
/**
 * @description: 
 * @return {*}
 * @Author: 王强
 * @Date: 2022-09-17 16:17:07
 * @LastEditTime: Do not edit
 * @LastEditors: 王强
 * @param {*} params data
 * 
 * {
 *  location: []  4326,
 *  richText:'',
 * 
 * }
 */

// 需要重新设计 用类来实现
export class RadarRender {

    constructor (params) {
        validateParams(['map', 'data'], params)
        this.radarLableVisible = true // 是否显示雷达标签

        this.vectorLayer = null
        this.data = params.data || []
        this.map = params.map
        this.style = params.style
        this.addRadarLayer(params)
    }
    addRadarLayer (params) {
        const vectorSource = new VectorSource({
            features: []
        })
        // 矢量标注图层
        this.vectorLayer = new VectorLayer({
            source: vectorSource,
        })
        params.map.addLayer(this.vectorLayer)
        this.addRadarFeatures()
        this.addRadarFeatures = null
        this.setStyle(this.style)
    }
    addRadarFeatures () {
        const features = []
        this.data.forEach(item => {
            // 添加 雷达半径 
            if (item.radius) {
                const radarAreaFeature = createRadarAreaFuture({
                    center: item.location,
                    distance: item.radius
                })
                radarAreaFeature.set("data", item)
                features.push(radarAreaFeature)
            }
            const radarFeature = createRadarFeature(item.location)
            radarFeature.set("data", item)
            features.push(radarFeature)
        })
        this.vectorLayer.getSource().addFeatures(features)
    }

    setStyle (style) {
        this.style = style
        if (this.style) {
            this.vectorLayer.setStyle(this.style)
        } else {
            this.vectorLayer.setStyle(radarStyle)
        }
    }

    setLayerVisible (visible) {
        this.vectorLayer.setVisible(visible)
    }
    getLayerVisible () {
        return this.vectorLayer.getVisible()
    }
}